@@ -13,6 +13,16 @@ if [ -z "$SED" ]; then
 fi
 echo "Done"
 
+echo -n "Checking for awk..."
+AWK=$(which awk)
+if [ -z "$AWK" ]; then
+  echo
+  echo "Rot[t]Log script requires GNU awk."
+  echo "Please install it before to run this script."
+  exit 99
+fi
+echo "Done"
+
 . ./VERSION
 
 source ./DefConf.inc
